# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ts_cop.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ts_cop.proto',
  package='ts_cop',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0cts_cop.proto\x12\x06ts_cop\"%\n\x06\x44INT32\x12\r\n\x05value\x18\x01 \x01(\x05\x12\x0c\n\x04time\x18\x02 \x01(\x01\"%\n\x06\x44INT64\x12\r\n\x05value\x18\x01 \x01(\x03\x12\x0c\n\x04time\x18\x02 \x01(\x01\"%\n\x06\x44\x46LOAT\x12\r\n\x05value\x18\x01 \x01(\x02\x12\x0c\n\x04time\x18\x02 \x01(\x01\"&\n\x07\x44\x44OUBLE\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x0c\n\x04time\x18\x02 \x01(\x01\"&\n\x07\x44STRING\x12\r\n\x05value\x18\x01 \x01(\t\x12\x0c\n\x04time\x18\x02 \x01(\x01\"$\n\x05\x44\x42OOL\x12\r\n\x05value\x18\x01 \x01(\x08\x12\x0c\n\x04time\x18\x02 \x01(\x01\"\x13\n\x02\x43I\x12\r\n\x05value\x18\x01 \x01(\t\"%\n\x06\x43IList\x12\x1b\n\x07\x63i_list\x18\x01 \x03(\x0b\x32\n.ts_cop.CI\"\xdb\x01\n\x02SI\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\r\n\x05ratio\x18\x02 \x01(\x01\x12\x11\n\tparent_id\x18\x03 \x01(\t\x12\r\n\x05si_id\x18\x04 \x01(\t\x12\x0f\n\x07\x63reated\x18\x05 \x01(\x01\x12\x13\n\x0blast_update\x18\x06 \x01(\x01\x12\x15\n\rstrategy_name\x18\x07 \x01(\t\x12\x11\n\tlive_mode\x18\x08 \x01(\x08\x12\x13\n\x0bstrategy_id\x18\t \x01(\t\x12\x11\n\tsymbol_id\x18\n \x01(\t\x12\x1c\n\x14parent_strategy_name\x18\x0b \x01(\t\"%\n\x06SIList\x12\x1b\n\x07si_list\x18\x01 \x03(\x0b\x32\n.ts_cop.SI\"\xbe\x03\n\x07TSOrder\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08quantity\x18\x02 \x01(\x01\x12\x15\n\rfill_quantity\x18\x03 \x01(\x01\x12\x11\n\tparent_id\x18\x04 \x01(\t\x12\x10\n\x08order_id\x18\x05 \x01(\t\x12\x19\n\x11platform_order_id\x18\x06 \x01(\t\x12\x0f\n\x07\x63reated\x18\x07 \x01(\x01\x12\x13\n\x0blast_update\x18\x08 \x01(\x01\x12\x15\n\rstrategy_name\x18\t \x01(\t\x12\x11\n\tlive_mode\x18\n \x01(\x08\x12\x13\n\x0bstrategy_id\x18\x0b \x01(\t\x12\x14\n\x0corder_status\x18\x0c \x01(\t\x12\x18\n\x10\x65xecution_broker\x18\r \x01(\t\x12\x17\n\x0f\x63learing_broker\x18\x0e \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x0f \x01(\t\x12\r\n\x05price\x18\x10 \x01(\x01\x12\x0b\n\x03\x66\x65\x65\x18\x11 \x01(\x01\x12\x10\n\x08\x65xchange\x18\x12 \x01(\t\x12\x0b\n\x03\x63\x63y\x18\x13 \x01(\t\x12\x0f\n\x07\x66\x65\x65_ccy\x18\x14 \x01(\t\x12\x11\n\tsymbol_id\x18\x15 \x01(\t\x12\x1c\n\x14parent_strategy_name\x18\x16 \x01(\t\"2\n\x0bTSOrderList\x12#\n\norder_list\x18\x01 \x03(\x0b\x32\x0f.ts_cop.TSOrder\"\xb7\x03\n\x07TSTrade\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08quantity\x18\x02 \x01(\x01\x12\x11\n\tparent_id\x18\x03 \x01(\t\x12\x10\n\x08trade_id\x18\x04 \x01(\t\x12\x0f\n\x07\x63reated\x18\x05 \x01(\x01\x12\x13\n\x0blast_update\x18\x06 \x01(\x01\x12\x15\n\rstrategy_name\x18\x07 \x01(\t\x12\x11\n\tlive_mode\x18\x08 \x01(\x08\x12\x13\n\x0bstrategy_id\x18\t \x01(\t\x12\x14\n\x0ctrade_status\x18\n \x01(\t\x12\x18\n\x10\x65xecution_broker\x18\x0b \x01(\t\x12\x17\n\x0f\x63learing_broker\x18\x0c \x01(\t\x12\x17\n\x0fsettlement_date\x18\r \x01(\x01\x12\x10\n\x08\x66x_ratio\x18\x0e \x01(\x01\x12\x0f\n\x07\x61\x63\x63ount\x18\x0f \x01(\t\x12\r\n\x05price\x18\x10 \x01(\x01\x12\x0b\n\x03\x66\x65\x65\x18\x11 \x01(\x01\x12\x10\n\x08\x65xchange\x18\x12 \x01(\t\x12\x0b\n\x03\x63\x63y\x18\x13 \x01(\t\x12\x0f\n\x07\x66\x65\x65_ccy\x18\x14 \x01(\t\x12\x11\n\tsymbol_id\x18\x15 \x01(\t\x12\x1c\n\x14parent_strategy_name\x18\x16 \x01(\t\"2\n\x0bTSTradeList\x12#\n\ntrade_list\x18\x01 \x03(\x0b\x32\x0f.ts_cop.TSTrade\"\xfb\x03\n\x06TSDATA\x12\x12\n\nint32_data\x18\x01 \x01(\x05\x12\x12\n\nint64_data\x18\x02 \x01(\x03\x12\x12\n\nfloat_data\x18\x03 \x01(\x02\x12\x13\n\x0b\x64ouble_data\x18\x04 \x01(\x01\x12\x13\n\x0bstring_data\x18\x05 \x01(\t\x12\x11\n\tbool_data\x18\x06 \x01(\x08\x12\'\n\norder_data\x18\x07 \x01(\x0b\x32\x13.ts_cop.TSOrderList\x12\'\n\ntrade_data\x18\x08 \x01(\x0b\x32\x13.ts_cop.TSTradeList\x12\x1f\n\x07si_data\x18\t \x01(\x0b\x32\x0e.ts_cop.SIList\x12\x1f\n\x07\x63i_data\x18\n \x01(\x0b\x32\x0e.ts_cop.CIList\x12$\n\x0c\x64_int32_data\x18\x0b \x01(\x0b\x32\x0e.ts_cop.DINT32\x12$\n\x0c\x64_int64_data\x18\x0c \x01(\x0b\x32\x0e.ts_cop.DINT64\x12$\n\x0c\x64_float_data\x18\r \x01(\x0b\x32\x0e.ts_cop.DFLOAT\x12&\n\rd_double_data\x18\x0e \x01(\x0b\x32\x0f.ts_cop.DDOUBLE\x12&\n\rd_string_data\x18\x0f \x01(\x0b\x32\x0f.ts_cop.DSTRING\x12\"\n\x0b\x64_bool_data\x18\x10 \x01(\x0b\x32\r.ts_cop.DBOOL\"\x90\x03\n\x03\x43op\x12\x0e\n\x06msg_id\x18\x01 \x01(\t\x12%\n\x08msg_type\x18\x02 \x01(\x0e\x32\x13.ts_cop.Cop.MsgType\x12\x0e\n\x06sender\x18\x03 \x01(\t\x12\x13\n\x0binstance_id\x18\x04 \x01(\x05\x12\x0f\n\x07seq_num\x18\x05 \x01(\x03\x12\x14\n\x0c\x63reated_time\x18\x06 \x01(\x01\x12\x13\n\x0bstrategy_id\x18\x07 \x01(\t\x12*\n\x08\x64\x61ta_map\x18\x08 \x03(\x0b\x32\x18.ts_cop.Cop.DataMapEntry\x1a>\n\x0c\x44\x61taMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.ts_cop.TSDATA:\x02\x38\x01\"0\n\x07MsgType\x12\x0b\n\x07Listing\x10\x00\x12\x0c\n\x08Strategy\x10\x01\x12\n\n\x06System\x10\x02\"S\n\x06\x46idNum\x12\t\n\x05\x44ummy\x10\x00\x12\x08\n\x02\x43I\x10\xd1\x86\x03\x12\x08\n\x02SI\x10\xd2\x86\x03\x12\x0b\n\x05Order\x10\xd3\x86\x03\x12\x0b\n\x05Trade\x10\xd4\x86\x03\x12\x10\n\nOrder_Snap\x10\xd5\x86\x03\x62\x06proto3'
)



_COP_MSGTYPE = _descriptor.EnumDescriptor(
  name='MsgType',
  full_name='ts_cop.Cop.MsgType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Listing', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Strategy', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='System', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2353,
  serialized_end=2401,
)
_sym_db.RegisterEnumDescriptor(_COP_MSGTYPE)

_COP_FIDNUM = _descriptor.EnumDescriptor(
  name='FidNum',
  full_name='ts_cop.Cop.FidNum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Dummy', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CI', index=1, number=50001,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SI', index=2, number=50002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Order', index=3, number=50003,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Trade', index=4, number=50004,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Order_Snap', index=5, number=50005,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2403,
  serialized_end=2486,
)
_sym_db.RegisterEnumDescriptor(_COP_FIDNUM)


_DINT32 = _descriptor.Descriptor(
  name='DINT32',
  full_name='ts_cop.DINT32',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='ts_cop.DINT32.value', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='ts_cop.DINT32.time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=61,
)


_DINT64 = _descriptor.Descriptor(
  name='DINT64',
  full_name='ts_cop.DINT64',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='ts_cop.DINT64.value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='ts_cop.DINT64.time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=100,
)


_DFLOAT = _descriptor.Descriptor(
  name='DFLOAT',
  full_name='ts_cop.DFLOAT',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='ts_cop.DFLOAT.value', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='ts_cop.DFLOAT.time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=139,
)


_DDOUBLE = _descriptor.Descriptor(
  name='DDOUBLE',
  full_name='ts_cop.DDOUBLE',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='ts_cop.DDOUBLE.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='ts_cop.DDOUBLE.time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=179,
)


_DSTRING = _descriptor.Descriptor(
  name='DSTRING',
  full_name='ts_cop.DSTRING',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='ts_cop.DSTRING.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='ts_cop.DSTRING.time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=219,
)


_DBOOL = _descriptor.Descriptor(
  name='DBOOL',
  full_name='ts_cop.DBOOL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='ts_cop.DBOOL.value', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='ts_cop.DBOOL.time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=257,
)


_CI = _descriptor.Descriptor(
  name='CI',
  full_name='ts_cop.CI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='ts_cop.CI.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=278,
)


_CILIST = _descriptor.Descriptor(
  name='CIList',
  full_name='ts_cop.CIList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ci_list', full_name='ts_cop.CIList.ci_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=317,
)


_SI = _descriptor.Descriptor(
  name='SI',
  full_name='ts_cop.SI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='ts_cop.SI.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ratio', full_name='ts_cop.SI.ratio', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='ts_cop.SI.parent_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='si_id', full_name='ts_cop.SI.si_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='ts_cop.SI.created', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update', full_name='ts_cop.SI.last_update', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strategy_name', full_name='ts_cop.SI.strategy_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='live_mode', full_name='ts_cop.SI.live_mode', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='ts_cop.SI.strategy_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol_id', full_name='ts_cop.SI.symbol_id', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_strategy_name', full_name='ts_cop.SI.parent_strategy_name', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=539,
)


_SILIST = _descriptor.Descriptor(
  name='SIList',
  full_name='ts_cop.SIList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='si_list', full_name='ts_cop.SIList.si_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=541,
  serialized_end=578,
)


_TSORDER = _descriptor.Descriptor(
  name='TSOrder',
  full_name='ts_cop.TSOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='ts_cop.TSOrder.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='ts_cop.TSOrder.quantity', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fill_quantity', full_name='ts_cop.TSOrder.fill_quantity', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='ts_cop.TSOrder.parent_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_id', full_name='ts_cop.TSOrder.order_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platform_order_id', full_name='ts_cop.TSOrder.platform_order_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='ts_cop.TSOrder.created', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update', full_name='ts_cop.TSOrder.last_update', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strategy_name', full_name='ts_cop.TSOrder.strategy_name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='live_mode', full_name='ts_cop.TSOrder.live_mode', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='ts_cop.TSOrder.strategy_id', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_status', full_name='ts_cop.TSOrder.order_status', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_broker', full_name='ts_cop.TSOrder.execution_broker', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clearing_broker', full_name='ts_cop.TSOrder.clearing_broker', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='ts_cop.TSOrder.account', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='ts_cop.TSOrder.price', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='ts_cop.TSOrder.fee', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='ts_cop.TSOrder.exchange', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ccy', full_name='ts_cop.TSOrder.ccy', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_ccy', full_name='ts_cop.TSOrder.fee_ccy', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol_id', full_name='ts_cop.TSOrder.symbol_id', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_strategy_name', full_name='ts_cop.TSOrder.parent_strategy_name', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=1027,
)


_TSORDERLIST = _descriptor.Descriptor(
  name='TSOrderList',
  full_name='ts_cop.TSOrderList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_list', full_name='ts_cop.TSOrderList.order_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1029,
  serialized_end=1079,
)


_TSTRADE = _descriptor.Descriptor(
  name='TSTrade',
  full_name='ts_cop.TSTrade',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='ts_cop.TSTrade.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='ts_cop.TSTrade.quantity', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='ts_cop.TSTrade.parent_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_id', full_name='ts_cop.TSTrade.trade_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='ts_cop.TSTrade.created', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update', full_name='ts_cop.TSTrade.last_update', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strategy_name', full_name='ts_cop.TSTrade.strategy_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='live_mode', full_name='ts_cop.TSTrade.live_mode', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='ts_cop.TSTrade.strategy_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_status', full_name='ts_cop.TSTrade.trade_status', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_broker', full_name='ts_cop.TSTrade.execution_broker', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clearing_broker', full_name='ts_cop.TSTrade.clearing_broker', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlement_date', full_name='ts_cop.TSTrade.settlement_date', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fx_ratio', full_name='ts_cop.TSTrade.fx_ratio', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='ts_cop.TSTrade.account', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='ts_cop.TSTrade.price', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='ts_cop.TSTrade.fee', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='ts_cop.TSTrade.exchange', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ccy', full_name='ts_cop.TSTrade.ccy', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_ccy', full_name='ts_cop.TSTrade.fee_ccy', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol_id', full_name='ts_cop.TSTrade.symbol_id', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_strategy_name', full_name='ts_cop.TSTrade.parent_strategy_name', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1082,
  serialized_end=1521,
)


_TSTRADELIST = _descriptor.Descriptor(
  name='TSTradeList',
  full_name='ts_cop.TSTradeList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trade_list', full_name='ts_cop.TSTradeList.trade_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1523,
  serialized_end=1573,
)


_TSDATA = _descriptor.Descriptor(
  name='TSDATA',
  full_name='ts_cop.TSDATA',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='int32_data', full_name='ts_cop.TSDATA.int32_data', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int64_data', full_name='ts_cop.TSDATA.int64_data', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float_data', full_name='ts_cop.TSDATA.float_data', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_data', full_name='ts_cop.TSDATA.double_data', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_data', full_name='ts_cop.TSDATA.string_data', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_data', full_name='ts_cop.TSDATA.bool_data', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_data', full_name='ts_cop.TSDATA.order_data', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_data', full_name='ts_cop.TSDATA.trade_data', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='si_data', full_name='ts_cop.TSDATA.si_data', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ci_data', full_name='ts_cop.TSDATA.ci_data', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d_int32_data', full_name='ts_cop.TSDATA.d_int32_data', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d_int64_data', full_name='ts_cop.TSDATA.d_int64_data', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d_float_data', full_name='ts_cop.TSDATA.d_float_data', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d_double_data', full_name='ts_cop.TSDATA.d_double_data', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d_string_data', full_name='ts_cop.TSDATA.d_string_data', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d_bool_data', full_name='ts_cop.TSDATA.d_bool_data', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1576,
  serialized_end=2083,
)


_COP_DATAMAPENTRY = _descriptor.Descriptor(
  name='DataMapEntry',
  full_name='ts_cop.Cop.DataMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ts_cop.Cop.DataMapEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ts_cop.Cop.DataMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2289,
  serialized_end=2351,
)

_COP = _descriptor.Descriptor(
  name='Cop',
  full_name='ts_cop.Cop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg_id', full_name='ts_cop.Cop.msg_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg_type', full_name='ts_cop.Cop.msg_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='ts_cop.Cop.sender', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='ts_cop.Cop.instance_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq_num', full_name='ts_cop.Cop.seq_num', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_time', full_name='ts_cop.Cop.created_time', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='ts_cop.Cop.strategy_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_map', full_name='ts_cop.Cop.data_map', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_COP_DATAMAPENTRY, ],
  enum_types=[
    _COP_MSGTYPE,
    _COP_FIDNUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2086,
  serialized_end=2486,
)

_CILIST.fields_by_name['ci_list'].message_type = _CI
_SILIST.fields_by_name['si_list'].message_type = _SI
_TSORDERLIST.fields_by_name['order_list'].message_type = _TSORDER
_TSTRADELIST.fields_by_name['trade_list'].message_type = _TSTRADE
_TSDATA.fields_by_name['order_data'].message_type = _TSORDERLIST
_TSDATA.fields_by_name['trade_data'].message_type = _TSTRADELIST
_TSDATA.fields_by_name['si_data'].message_type = _SILIST
_TSDATA.fields_by_name['ci_data'].message_type = _CILIST
_TSDATA.fields_by_name['d_int32_data'].message_type = _DINT32
_TSDATA.fields_by_name['d_int64_data'].message_type = _DINT64
_TSDATA.fields_by_name['d_float_data'].message_type = _DFLOAT
_TSDATA.fields_by_name['d_double_data'].message_type = _DDOUBLE
_TSDATA.fields_by_name['d_string_data'].message_type = _DSTRING
_TSDATA.fields_by_name['d_bool_data'].message_type = _DBOOL
_COP_DATAMAPENTRY.fields_by_name['value'].message_type = _TSDATA
_COP_DATAMAPENTRY.containing_type = _COP
_COP.fields_by_name['msg_type'].enum_type = _COP_MSGTYPE
_COP.fields_by_name['data_map'].message_type = _COP_DATAMAPENTRY
_COP_MSGTYPE.containing_type = _COP
_COP_FIDNUM.containing_type = _COP
DESCRIPTOR.message_types_by_name['DINT32'] = _DINT32
DESCRIPTOR.message_types_by_name['DINT64'] = _DINT64
DESCRIPTOR.message_types_by_name['DFLOAT'] = _DFLOAT
DESCRIPTOR.message_types_by_name['DDOUBLE'] = _DDOUBLE
DESCRIPTOR.message_types_by_name['DSTRING'] = _DSTRING
DESCRIPTOR.message_types_by_name['DBOOL'] = _DBOOL
DESCRIPTOR.message_types_by_name['CI'] = _CI
DESCRIPTOR.message_types_by_name['CIList'] = _CILIST
DESCRIPTOR.message_types_by_name['SI'] = _SI
DESCRIPTOR.message_types_by_name['SIList'] = _SILIST
DESCRIPTOR.message_types_by_name['TSOrder'] = _TSORDER
DESCRIPTOR.message_types_by_name['TSOrderList'] = _TSORDERLIST
DESCRIPTOR.message_types_by_name['TSTrade'] = _TSTRADE
DESCRIPTOR.message_types_by_name['TSTradeList'] = _TSTRADELIST
DESCRIPTOR.message_types_by_name['TSDATA'] = _TSDATA
DESCRIPTOR.message_types_by_name['Cop'] = _COP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DINT32 = _reflection.GeneratedProtocolMessageType('DINT32', (_message.Message,), {
  'DESCRIPTOR' : _DINT32,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.DINT32)
  })
_sym_db.RegisterMessage(DINT32)

DINT64 = _reflection.GeneratedProtocolMessageType('DINT64', (_message.Message,), {
  'DESCRIPTOR' : _DINT64,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.DINT64)
  })
_sym_db.RegisterMessage(DINT64)

DFLOAT = _reflection.GeneratedProtocolMessageType('DFLOAT', (_message.Message,), {
  'DESCRIPTOR' : _DFLOAT,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.DFLOAT)
  })
_sym_db.RegisterMessage(DFLOAT)

DDOUBLE = _reflection.GeneratedProtocolMessageType('DDOUBLE', (_message.Message,), {
  'DESCRIPTOR' : _DDOUBLE,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.DDOUBLE)
  })
_sym_db.RegisterMessage(DDOUBLE)

DSTRING = _reflection.GeneratedProtocolMessageType('DSTRING', (_message.Message,), {
  'DESCRIPTOR' : _DSTRING,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.DSTRING)
  })
_sym_db.RegisterMessage(DSTRING)

DBOOL = _reflection.GeneratedProtocolMessageType('DBOOL', (_message.Message,), {
  'DESCRIPTOR' : _DBOOL,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.DBOOL)
  })
_sym_db.RegisterMessage(DBOOL)

CI = _reflection.GeneratedProtocolMessageType('CI', (_message.Message,), {
  'DESCRIPTOR' : _CI,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.CI)
  })
_sym_db.RegisterMessage(CI)

CIList = _reflection.GeneratedProtocolMessageType('CIList', (_message.Message,), {
  'DESCRIPTOR' : _CILIST,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.CIList)
  })
_sym_db.RegisterMessage(CIList)

SI = _reflection.GeneratedProtocolMessageType('SI', (_message.Message,), {
  'DESCRIPTOR' : _SI,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.SI)
  })
_sym_db.RegisterMessage(SI)

SIList = _reflection.GeneratedProtocolMessageType('SIList', (_message.Message,), {
  'DESCRIPTOR' : _SILIST,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.SIList)
  })
_sym_db.RegisterMessage(SIList)

TSOrder = _reflection.GeneratedProtocolMessageType('TSOrder', (_message.Message,), {
  'DESCRIPTOR' : _TSORDER,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.TSOrder)
  })
_sym_db.RegisterMessage(TSOrder)

TSOrderList = _reflection.GeneratedProtocolMessageType('TSOrderList', (_message.Message,), {
  'DESCRIPTOR' : _TSORDERLIST,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.TSOrderList)
  })
_sym_db.RegisterMessage(TSOrderList)

TSTrade = _reflection.GeneratedProtocolMessageType('TSTrade', (_message.Message,), {
  'DESCRIPTOR' : _TSTRADE,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.TSTrade)
  })
_sym_db.RegisterMessage(TSTrade)

TSTradeList = _reflection.GeneratedProtocolMessageType('TSTradeList', (_message.Message,), {
  'DESCRIPTOR' : _TSTRADELIST,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.TSTradeList)
  })
_sym_db.RegisterMessage(TSTradeList)

TSDATA = _reflection.GeneratedProtocolMessageType('TSDATA', (_message.Message,), {
  'DESCRIPTOR' : _TSDATA,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.TSDATA)
  })
_sym_db.RegisterMessage(TSDATA)

Cop = _reflection.GeneratedProtocolMessageType('Cop', (_message.Message,), {

  'DataMapEntry' : _reflection.GeneratedProtocolMessageType('DataMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _COP_DATAMAPENTRY,
    '__module__' : 'ts_cop_pb2'
    # @@protoc_insertion_point(class_scope:ts_cop.Cop.DataMapEntry)
    })
  ,
  'DESCRIPTOR' : _COP,
  '__module__' : 'ts_cop_pb2'
  # @@protoc_insertion_point(class_scope:ts_cop.Cop)
  })
_sym_db.RegisterMessage(Cop)
_sym_db.RegisterMessage(Cop.DataMapEntry)


_COP_DATAMAPENTRY._options = None
# @@protoc_insertion_point(module_scope)
