
syntax = "proto3";

package magpie;

// The magpie service definition.
service Magpie {
    // Unary - request and respond
    rpc HealthCheck (Ping) returns (Pong);
    rpc UpdateRefDataPriceFromQC (UpdateRefDataPriceFromQC_Msg) returns (NoneReply);
    rpc UpdateRefDataFromQC (UpdateRefDataFromQC_Msg) returns (NoneReply);
}

message Ping {
    string message = 1;
}

message Pong {
    string message = 1;
}

message UpdateRefDataPriceFromQC_Msg {
    string data = 1;
}

message UpdateRefDataFromQC_Msg {
    string data = 1;
}

message NoneReply {
    string reply = 1;
}
