# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eagle.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eagle.proto',
  package='eagle',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0b\x65\x61gle.proto\x12\x05\x65\x61gle\"c\n\x19GetBacktestWarmupData_Msg\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\x0e\n\x06msg_id\x18\x02 \x01(\t\x12\x10\n\x08msg_type\x18\x03 \x01(\x05\x12\x0f\n\x07\x66id_num\x18\x04 \x01(\x05\"+\n\x1bGetBacktestWarmupData_Reply\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"*\n\x10GetUSLEIData_Msg\x12\x16\n\x0elookback_month\x18\x01 \x01(\x05\"\x8f\x01\n\x12GetUSLEIData_Reply\x12\x44\n\x0fus_lei_data_map\x18\x01 \x03(\x0b\x32+.eagle.GetUSLEIData_Reply.UsLeiDataMapEntry\x1a\x33\n\x11UsLeiDataMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x17GetDataByStrategyId_Msg\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\"\x80\x01\n\x19GetDataByStrategyId_Reply\x12\x0b\n\x03\x63\x66g\x18\x01 \x03(\t\x12\n\n\x02\x63i\x18\x02 \x03(\t\x12\n\n\x02si\x18\x03 \x01(\t\x12\x10\n\x08ord_snap\x18\x04 \x01(\t\x12\x10\n\x08ord_hist\x18\x05 \x01(\t\x12\x0b\n\x03trd\x18\x06 \x01(\t\x12\r\n\x05price\x18\x07 \x01(\t\"\x17\n\x04Ping\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x17\n\x04Pong\x12\x0f\n\x07message\x18\x01 \x01(\t2\xac\x02\n\x05\x45\x61gle\x12\'\n\x0bHealthCheck\x12\x0b.eagle.Ping\x1a\x0b.eagle.Pong\x12W\n\x13GetDataByStrategyId\x12\x1e.eagle.GetDataByStrategyId_Msg\x1a .eagle.GetDataByStrategyId_Reply\x12]\n\x15GetBacktestWarmupData\x12 .eagle.GetBacktestWarmupData_Msg\x1a\".eagle.GetBacktestWarmupData_Reply\x12\x42\n\x0cGetUSLEIData\x12\x17.eagle.GetUSLEIData_Msg\x1a\x19.eagle.GetUSLEIData_Replyb\x06proto3'
)




_GETBACKTESTWARMUPDATA_MSG = _descriptor.Descriptor(
  name='GetBacktestWarmupData_Msg',
  full_name='eagle.GetBacktestWarmupData_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='eagle.GetBacktestWarmupData_Msg.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg_id', full_name='eagle.GetBacktestWarmupData_Msg.msg_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg_type', full_name='eagle.GetBacktestWarmupData_Msg.msg_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fid_num', full_name='eagle.GetBacktestWarmupData_Msg.fid_num', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=121,
)


_GETBACKTESTWARMUPDATA_REPLY = _descriptor.Descriptor(
  name='GetBacktestWarmupData_Reply',
  full_name='eagle.GetBacktestWarmupData_Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='eagle.GetBacktestWarmupData_Reply.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=166,
)


_GETUSLEIDATA_MSG = _descriptor.Descriptor(
  name='GetUSLEIData_Msg',
  full_name='eagle.GetUSLEIData_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lookback_month', full_name='eagle.GetUSLEIData_Msg.lookback_month', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=168,
  serialized_end=210,
)


_GETUSLEIDATA_REPLY_USLEIDATAMAPENTRY = _descriptor.Descriptor(
  name='UsLeiDataMapEntry',
  full_name='eagle.GetUSLEIData_Reply.UsLeiDataMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eagle.GetUSLEIData_Reply.UsLeiDataMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eagle.GetUSLEIData_Reply.UsLeiDataMapEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=356,
)

_GETUSLEIDATA_REPLY = _descriptor.Descriptor(
  name='GetUSLEIData_Reply',
  full_name='eagle.GetUSLEIData_Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='us_lei_data_map', full_name='eagle.GetUSLEIData_Reply.us_lei_data_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETUSLEIDATA_REPLY_USLEIDATAMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=356,
)


_GETDATABYSTRATEGYID_MSG = _descriptor.Descriptor(
  name='GetDataByStrategyId_Msg',
  full_name='eagle.GetDataByStrategyId_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='eagle.GetDataByStrategyId_Msg.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=404,
)


_GETDATABYSTRATEGYID_REPLY = _descriptor.Descriptor(
  name='GetDataByStrategyId_Reply',
  full_name='eagle.GetDataByStrategyId_Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cfg', full_name='eagle.GetDataByStrategyId_Reply.cfg', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ci', full_name='eagle.GetDataByStrategyId_Reply.ci', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='si', full_name='eagle.GetDataByStrategyId_Reply.si', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ord_snap', full_name='eagle.GetDataByStrategyId_Reply.ord_snap', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ord_hist', full_name='eagle.GetDataByStrategyId_Reply.ord_hist', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trd', full_name='eagle.GetDataByStrategyId_Reply.trd', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='eagle.GetDataByStrategyId_Reply.price', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=535,
)


_PING = _descriptor.Descriptor(
  name='Ping',
  full_name='eagle.Ping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='eagle.Ping.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=560,
)


_PONG = _descriptor.Descriptor(
  name='Pong',
  full_name='eagle.Pong',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='eagle.Pong.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=562,
  serialized_end=585,
)

_GETUSLEIDATA_REPLY_USLEIDATAMAPENTRY.containing_type = _GETUSLEIDATA_REPLY
_GETUSLEIDATA_REPLY.fields_by_name['us_lei_data_map'].message_type = _GETUSLEIDATA_REPLY_USLEIDATAMAPENTRY
DESCRIPTOR.message_types_by_name['GetBacktestWarmupData_Msg'] = _GETBACKTESTWARMUPDATA_MSG
DESCRIPTOR.message_types_by_name['GetBacktestWarmupData_Reply'] = _GETBACKTESTWARMUPDATA_REPLY
DESCRIPTOR.message_types_by_name['GetUSLEIData_Msg'] = _GETUSLEIDATA_MSG
DESCRIPTOR.message_types_by_name['GetUSLEIData_Reply'] = _GETUSLEIDATA_REPLY
DESCRIPTOR.message_types_by_name['GetDataByStrategyId_Msg'] = _GETDATABYSTRATEGYID_MSG
DESCRIPTOR.message_types_by_name['GetDataByStrategyId_Reply'] = _GETDATABYSTRATEGYID_REPLY
DESCRIPTOR.message_types_by_name['Ping'] = _PING
DESCRIPTOR.message_types_by_name['Pong'] = _PONG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetBacktestWarmupData_Msg = _reflection.GeneratedProtocolMessageType('GetBacktestWarmupData_Msg', (_message.Message,), {
  'DESCRIPTOR' : _GETBACKTESTWARMUPDATA_MSG,
  '__module__' : 'eagle_pb2'
  # @@protoc_insertion_point(class_scope:eagle.GetBacktestWarmupData_Msg)
  })
_sym_db.RegisterMessage(GetBacktestWarmupData_Msg)

GetBacktestWarmupData_Reply = _reflection.GeneratedProtocolMessageType('GetBacktestWarmupData_Reply', (_message.Message,), {
  'DESCRIPTOR' : _GETBACKTESTWARMUPDATA_REPLY,
  '__module__' : 'eagle_pb2'
  # @@protoc_insertion_point(class_scope:eagle.GetBacktestWarmupData_Reply)
  })
_sym_db.RegisterMessage(GetBacktestWarmupData_Reply)

GetUSLEIData_Msg = _reflection.GeneratedProtocolMessageType('GetUSLEIData_Msg', (_message.Message,), {
  'DESCRIPTOR' : _GETUSLEIDATA_MSG,
  '__module__' : 'eagle_pb2'
  # @@protoc_insertion_point(class_scope:eagle.GetUSLEIData_Msg)
  })
_sym_db.RegisterMessage(GetUSLEIData_Msg)

GetUSLEIData_Reply = _reflection.GeneratedProtocolMessageType('GetUSLEIData_Reply', (_message.Message,), {

  'UsLeiDataMapEntry' : _reflection.GeneratedProtocolMessageType('UsLeiDataMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETUSLEIDATA_REPLY_USLEIDATAMAPENTRY,
    '__module__' : 'eagle_pb2'
    # @@protoc_insertion_point(class_scope:eagle.GetUSLEIData_Reply.UsLeiDataMapEntry)
    })
  ,
  'DESCRIPTOR' : _GETUSLEIDATA_REPLY,
  '__module__' : 'eagle_pb2'
  # @@protoc_insertion_point(class_scope:eagle.GetUSLEIData_Reply)
  })
_sym_db.RegisterMessage(GetUSLEIData_Reply)
_sym_db.RegisterMessage(GetUSLEIData_Reply.UsLeiDataMapEntry)

GetDataByStrategyId_Msg = _reflection.GeneratedProtocolMessageType('GetDataByStrategyId_Msg', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABYSTRATEGYID_MSG,
  '__module__' : 'eagle_pb2'
  # @@protoc_insertion_point(class_scope:eagle.GetDataByStrategyId_Msg)
  })
_sym_db.RegisterMessage(GetDataByStrategyId_Msg)

GetDataByStrategyId_Reply = _reflection.GeneratedProtocolMessageType('GetDataByStrategyId_Reply', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABYSTRATEGYID_REPLY,
  '__module__' : 'eagle_pb2'
  # @@protoc_insertion_point(class_scope:eagle.GetDataByStrategyId_Reply)
  })
_sym_db.RegisterMessage(GetDataByStrategyId_Reply)

Ping = _reflection.GeneratedProtocolMessageType('Ping', (_message.Message,), {
  'DESCRIPTOR' : _PING,
  '__module__' : 'eagle_pb2'
  # @@protoc_insertion_point(class_scope:eagle.Ping)
  })
_sym_db.RegisterMessage(Ping)

Pong = _reflection.GeneratedProtocolMessageType('Pong', (_message.Message,), {
  'DESCRIPTOR' : _PONG,
  '__module__' : 'eagle_pb2'
  # @@protoc_insertion_point(class_scope:eagle.Pong)
  })
_sym_db.RegisterMessage(Pong)


_GETUSLEIDATA_REPLY_USLEIDATAMAPENTRY._options = None

_EAGLE = _descriptor.ServiceDescriptor(
  name='Eagle',
  full_name='eagle.Eagle',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=588,
  serialized_end=888,
  methods=[
  _descriptor.MethodDescriptor(
    name='HealthCheck',
    full_name='eagle.Eagle.HealthCheck',
    index=0,
    containing_service=None,
    input_type=_PING,
    output_type=_PONG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataByStrategyId',
    full_name='eagle.Eagle.GetDataByStrategyId',
    index=1,
    containing_service=None,
    input_type=_GETDATABYSTRATEGYID_MSG,
    output_type=_GETDATABYSTRATEGYID_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBacktestWarmupData',
    full_name='eagle.Eagle.GetBacktestWarmupData',
    index=2,
    containing_service=None,
    input_type=_GETBACKTESTWARMUPDATA_MSG,
    output_type=_GETBACKTESTWARMUPDATA_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUSLEIData',
    full_name='eagle.Eagle.GetUSLEIData',
    index=3,
    containing_service=None,
    input_type=_GETUSLEIDATA_MSG,
    output_type=_GETUSLEIDATA_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EAGLE)

DESCRIPTOR.services_by_name['Eagle'] = _EAGLE

# @@protoc_insertion_point(module_scope)
