# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peacock.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='peacock.proto',
  package='peacock',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rpeacock.proto\x12\x07peacock\".\n\x17GetDataByStrategyId_Msg\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\"\x80\x01\n\x19GetDataByStrategyId_Reply\x12\x0b\n\x03\x63\x66g\x18\x01 \x03(\t\x12\n\n\x02\x63i\x18\x02 \x03(\t\x12\n\n\x02si\x18\x03 \x01(\t\x12\x10\n\x08ord_snap\x18\x04 \x01(\t\x12\x10\n\x08ord_hist\x18\x05 \x01(\t\x12\x0b\n\x03trd\x18\x06 \x01(\t\x12\r\n\x05price\x18\x07 \x01(\t\"c\n\x19GetBacktestWarmupData_Msg\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\x0e\n\x06msg_id\x18\x02 \x01(\t\x12\x10\n\x08msg_type\x18\x03 \x01(\x05\x12\x0f\n\x07\x66id_num\x18\x04 \x01(\x05\"+\n\x1bGetBacktestWarmupData_Reply\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"*\n\x10GetUSLEIData_Msg\x12\x16\n\x0elookback_month\x18\x01 \x01(\x05\"\x91\x01\n\x12GetUSLEIData_Reply\x12\x46\n\x0fus_lei_data_map\x18\x01 \x03(\x0b\x32-.peacock.GetUSLEIData_Reply.UsLeiDataMapEntry\x1a\x33\n\x11UsLeiDataMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\n\x18RemoveStrategyConfig_Msg\x12\x15\n\rstrategy_name\x18\x01 \x01(\t\x12\x0f\n\x07is_live\x18\x02 \x01(\x08\x12\x18\n\x10strategy_id_list\x18\x03 \x03(\t\"#\n\x13RemoveOldConfig_Msg\x12\x0c\n\x04\x64\x61ys\x18\x01 \x01(\x05\"\x1c\n\x0b\x44ummy_Reply\x12\r\n\x05\x64ummy\x18\x01 \x01(\t\"?\n\x15GetStrategyConfig_Msg\x12\x15\n\rstrategy_name\x18\x01 \x01(\t\x12\x0f\n\x07is_live\x18\x02 \x01(\x08\";\n\x17GetStrategyConfig_Reply\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x10\n\x08\x63\x66g_list\x18\x02 \x03(\t\"1\n\x16SaveStrategyConfig_Msg\x12\x17\n\x0fstrategy_config\x18\x01 \x01(\t\"*\n\x18SaveStrategyConfig_Reply\x12\x0e\n\x06status\x18\x01 \x01(\t\">\n\x13SaveFileToColud_Msg\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x14\n\x0c\x66ile_content\x18\x02 \x01(\t\"Z\n\x1aSaveRefDataPriceFromQC_Msg\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x14\n\x0c\x66ile_content\x18\x02 \x01(\t\x12\x13\n\x0b\x61\x63tion_mode\x18\x03 \x01(\t\"U\n\x15SaveRefDataFromQC_Msg\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x14\n\x0c\x66ile_content\x18\x02 \x01(\t\x12\x13\n\x0b\x61\x63tion_mode\x18\x03 \x01(\t\"\x1a\n\tNoneReply\x12\r\n\x05reply\x18\x01 \x01(\t\"\x17\n\x04Ping\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x17\n\x04Pong\x12\x0f\n\x07message\x18\x01 \x01(\t2\xe8\x06\n\x07Peacock\x12\x43\n\x0fSaveFileToColud\x12\x1c.peacock.SaveFileToColud_Msg\x1a\x12.peacock.NoneReply\x12Q\n\x16SaveRefDataPriceFromQC\x12#.peacock.SaveRefDataPriceFromQC_Msg\x1a\x12.peacock.NoneReply\x12G\n\x11SaveRefDataFromQC\x12\x1e.peacock.SaveRefDataFromQC_Msg\x1a\x12.peacock.NoneReply\x12X\n\x12SaveStrategyConfig\x12\x1f.peacock.SaveStrategyConfig_Msg\x1a!.peacock.SaveStrategyConfig_Reply\x12U\n\x11GetStrategyConfig\x12\x1e.peacock.GetStrategyConfig_Msg\x1a .peacock.GetStrategyConfig_Reply\x12O\n\x14RemoveStrategyConfig\x12!.peacock.RemoveStrategyConfig_Msg\x1a\x14.peacock.Dummy_Reply\x12\x45\n\x0fRemoveOldConfig\x12\x1c.peacock.RemoveOldConfig_Msg\x1a\x14.peacock.Dummy_Reply\x12[\n\x13GetDataByStrategyId\x12 .peacock.GetDataByStrategyId_Msg\x1a\".peacock.GetDataByStrategyId_Reply\x12\x61\n\x15GetBacktestWarmupData\x12\".peacock.GetBacktestWarmupData_Msg\x1a$.peacock.GetBacktestWarmupData_Reply\x12\x46\n\x0cGetUSLEIData\x12\x19.peacock.GetUSLEIData_Msg\x1a\x1b.peacock.GetUSLEIData_Reply\x12+\n\x0bHealthCheck\x12\r.peacock.Ping\x1a\r.peacock.Pongb\x06proto3'
)




_GETDATABYSTRATEGYID_MSG = _descriptor.Descriptor(
  name='GetDataByStrategyId_Msg',
  full_name='peacock.GetDataByStrategyId_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='peacock.GetDataByStrategyId_Msg.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=72,
)


_GETDATABYSTRATEGYID_REPLY = _descriptor.Descriptor(
  name='GetDataByStrategyId_Reply',
  full_name='peacock.GetDataByStrategyId_Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cfg', full_name='peacock.GetDataByStrategyId_Reply.cfg', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ci', full_name='peacock.GetDataByStrategyId_Reply.ci', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='si', full_name='peacock.GetDataByStrategyId_Reply.si', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ord_snap', full_name='peacock.GetDataByStrategyId_Reply.ord_snap', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ord_hist', full_name='peacock.GetDataByStrategyId_Reply.ord_hist', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trd', full_name='peacock.GetDataByStrategyId_Reply.trd', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='peacock.GetDataByStrategyId_Reply.price', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=203,
)


_GETBACKTESTWARMUPDATA_MSG = _descriptor.Descriptor(
  name='GetBacktestWarmupData_Msg',
  full_name='peacock.GetBacktestWarmupData_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='peacock.GetBacktestWarmupData_Msg.strategy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg_id', full_name='peacock.GetBacktestWarmupData_Msg.msg_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg_type', full_name='peacock.GetBacktestWarmupData_Msg.msg_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fid_num', full_name='peacock.GetBacktestWarmupData_Msg.fid_num', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=304,
)


_GETBACKTESTWARMUPDATA_REPLY = _descriptor.Descriptor(
  name='GetBacktestWarmupData_Reply',
  full_name='peacock.GetBacktestWarmupData_Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='peacock.GetBacktestWarmupData_Reply.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=306,
  serialized_end=349,
)


_GETUSLEIDATA_MSG = _descriptor.Descriptor(
  name='GetUSLEIData_Msg',
  full_name='peacock.GetUSLEIData_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lookback_month', full_name='peacock.GetUSLEIData_Msg.lookback_month', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=351,
  serialized_end=393,
)


_GETUSLEIDATA_REPLY_USLEIDATAMAPENTRY = _descriptor.Descriptor(
  name='UsLeiDataMapEntry',
  full_name='peacock.GetUSLEIData_Reply.UsLeiDataMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='peacock.GetUSLEIData_Reply.UsLeiDataMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='peacock.GetUSLEIData_Reply.UsLeiDataMapEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=490,
  serialized_end=541,
)

_GETUSLEIDATA_REPLY = _descriptor.Descriptor(
  name='GetUSLEIData_Reply',
  full_name='peacock.GetUSLEIData_Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='us_lei_data_map', full_name='peacock.GetUSLEIData_Reply.us_lei_data_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETUSLEIDATA_REPLY_USLEIDATAMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=541,
)


_REMOVESTRATEGYCONFIG_MSG = _descriptor.Descriptor(
  name='RemoveStrategyConfig_Msg',
  full_name='peacock.RemoveStrategyConfig_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_name', full_name='peacock.RemoveStrategyConfig_Msg.strategy_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_live', full_name='peacock.RemoveStrategyConfig_Msg.is_live', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strategy_id_list', full_name='peacock.RemoveStrategyConfig_Msg.strategy_id_list', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=543,
  serialized_end=635,
)


_REMOVEOLDCONFIG_MSG = _descriptor.Descriptor(
  name='RemoveOldConfig_Msg',
  full_name='peacock.RemoveOldConfig_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='days', full_name='peacock.RemoveOldConfig_Msg.days', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=637,
  serialized_end=672,
)


_DUMMY_REPLY = _descriptor.Descriptor(
  name='Dummy_Reply',
  full_name='peacock.Dummy_Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dummy', full_name='peacock.Dummy_Reply.dummy', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=702,
)


_GETSTRATEGYCONFIG_MSG = _descriptor.Descriptor(
  name='GetStrategyConfig_Msg',
  full_name='peacock.GetStrategyConfig_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_name', full_name='peacock.GetStrategyConfig_Msg.strategy_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_live', full_name='peacock.GetStrategyConfig_Msg.is_live', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=704,
  serialized_end=767,
)


_GETSTRATEGYCONFIG_REPLY = _descriptor.Descriptor(
  name='GetStrategyConfig_Reply',
  full_name='peacock.GetStrategyConfig_Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='peacock.GetStrategyConfig_Reply.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cfg_list', full_name='peacock.GetStrategyConfig_Reply.cfg_list', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=769,
  serialized_end=828,
)


_SAVESTRATEGYCONFIG_MSG = _descriptor.Descriptor(
  name='SaveStrategyConfig_Msg',
  full_name='peacock.SaveStrategyConfig_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_config', full_name='peacock.SaveStrategyConfig_Msg.strategy_config', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=830,
  serialized_end=879,
)


_SAVESTRATEGYCONFIG_REPLY = _descriptor.Descriptor(
  name='SaveStrategyConfig_Reply',
  full_name='peacock.SaveStrategyConfig_Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='peacock.SaveStrategyConfig_Reply.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=881,
  serialized_end=923,
)


_SAVEFILETOCOLUD_MSG = _descriptor.Descriptor(
  name='SaveFileToColud_Msg',
  full_name='peacock.SaveFileToColud_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_name', full_name='peacock.SaveFileToColud_Msg.file_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_content', full_name='peacock.SaveFileToColud_Msg.file_content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=925,
  serialized_end=987,
)


_SAVEREFDATAPRICEFROMQC_MSG = _descriptor.Descriptor(
  name='SaveRefDataPriceFromQC_Msg',
  full_name='peacock.SaveRefDataPriceFromQC_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_name', full_name='peacock.SaveRefDataPriceFromQC_Msg.file_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_content', full_name='peacock.SaveRefDataPriceFromQC_Msg.file_content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action_mode', full_name='peacock.SaveRefDataPriceFromQC_Msg.action_mode', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=989,
  serialized_end=1079,
)


_SAVEREFDATAFROMQC_MSG = _descriptor.Descriptor(
  name='SaveRefDataFromQC_Msg',
  full_name='peacock.SaveRefDataFromQC_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_name', full_name='peacock.SaveRefDataFromQC_Msg.file_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_content', full_name='peacock.SaveRefDataFromQC_Msg.file_content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action_mode', full_name='peacock.SaveRefDataFromQC_Msg.action_mode', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1081,
  serialized_end=1166,
)


_NONEREPLY = _descriptor.Descriptor(
  name='NoneReply',
  full_name='peacock.NoneReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reply', full_name='peacock.NoneReply.reply', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1168,
  serialized_end=1194,
)


_PING = _descriptor.Descriptor(
  name='Ping',
  full_name='peacock.Ping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='peacock.Ping.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1196,
  serialized_end=1219,
)


_PONG = _descriptor.Descriptor(
  name='Pong',
  full_name='peacock.Pong',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='peacock.Pong.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1221,
  serialized_end=1244,
)

_GETUSLEIDATA_REPLY_USLEIDATAMAPENTRY.containing_type = _GETUSLEIDATA_REPLY
_GETUSLEIDATA_REPLY.fields_by_name['us_lei_data_map'].message_type = _GETUSLEIDATA_REPLY_USLEIDATAMAPENTRY
DESCRIPTOR.message_types_by_name['GetDataByStrategyId_Msg'] = _GETDATABYSTRATEGYID_MSG
DESCRIPTOR.message_types_by_name['GetDataByStrategyId_Reply'] = _GETDATABYSTRATEGYID_REPLY
DESCRIPTOR.message_types_by_name['GetBacktestWarmupData_Msg'] = _GETBACKTESTWARMUPDATA_MSG
DESCRIPTOR.message_types_by_name['GetBacktestWarmupData_Reply'] = _GETBACKTESTWARMUPDATA_REPLY
DESCRIPTOR.message_types_by_name['GetUSLEIData_Msg'] = _GETUSLEIDATA_MSG
DESCRIPTOR.message_types_by_name['GetUSLEIData_Reply'] = _GETUSLEIDATA_REPLY
DESCRIPTOR.message_types_by_name['RemoveStrategyConfig_Msg'] = _REMOVESTRATEGYCONFIG_MSG
DESCRIPTOR.message_types_by_name['RemoveOldConfig_Msg'] = _REMOVEOLDCONFIG_MSG
DESCRIPTOR.message_types_by_name['Dummy_Reply'] = _DUMMY_REPLY
DESCRIPTOR.message_types_by_name['GetStrategyConfig_Msg'] = _GETSTRATEGYCONFIG_MSG
DESCRIPTOR.message_types_by_name['GetStrategyConfig_Reply'] = _GETSTRATEGYCONFIG_REPLY
DESCRIPTOR.message_types_by_name['SaveStrategyConfig_Msg'] = _SAVESTRATEGYCONFIG_MSG
DESCRIPTOR.message_types_by_name['SaveStrategyConfig_Reply'] = _SAVESTRATEGYCONFIG_REPLY
DESCRIPTOR.message_types_by_name['SaveFileToColud_Msg'] = _SAVEFILETOCOLUD_MSG
DESCRIPTOR.message_types_by_name['SaveRefDataPriceFromQC_Msg'] = _SAVEREFDATAPRICEFROMQC_MSG
DESCRIPTOR.message_types_by_name['SaveRefDataFromQC_Msg'] = _SAVEREFDATAFROMQC_MSG
DESCRIPTOR.message_types_by_name['NoneReply'] = _NONEREPLY
DESCRIPTOR.message_types_by_name['Ping'] = _PING
DESCRIPTOR.message_types_by_name['Pong'] = _PONG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetDataByStrategyId_Msg = _reflection.GeneratedProtocolMessageType('GetDataByStrategyId_Msg', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABYSTRATEGYID_MSG,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.GetDataByStrategyId_Msg)
  })
_sym_db.RegisterMessage(GetDataByStrategyId_Msg)

GetDataByStrategyId_Reply = _reflection.GeneratedProtocolMessageType('GetDataByStrategyId_Reply', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABYSTRATEGYID_REPLY,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.GetDataByStrategyId_Reply)
  })
_sym_db.RegisterMessage(GetDataByStrategyId_Reply)

GetBacktestWarmupData_Msg = _reflection.GeneratedProtocolMessageType('GetBacktestWarmupData_Msg', (_message.Message,), {
  'DESCRIPTOR' : _GETBACKTESTWARMUPDATA_MSG,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.GetBacktestWarmupData_Msg)
  })
_sym_db.RegisterMessage(GetBacktestWarmupData_Msg)

GetBacktestWarmupData_Reply = _reflection.GeneratedProtocolMessageType('GetBacktestWarmupData_Reply', (_message.Message,), {
  'DESCRIPTOR' : _GETBACKTESTWARMUPDATA_REPLY,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.GetBacktestWarmupData_Reply)
  })
_sym_db.RegisterMessage(GetBacktestWarmupData_Reply)

GetUSLEIData_Msg = _reflection.GeneratedProtocolMessageType('GetUSLEIData_Msg', (_message.Message,), {
  'DESCRIPTOR' : _GETUSLEIDATA_MSG,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.GetUSLEIData_Msg)
  })
_sym_db.RegisterMessage(GetUSLEIData_Msg)

GetUSLEIData_Reply = _reflection.GeneratedProtocolMessageType('GetUSLEIData_Reply', (_message.Message,), {

  'UsLeiDataMapEntry' : _reflection.GeneratedProtocolMessageType('UsLeiDataMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETUSLEIDATA_REPLY_USLEIDATAMAPENTRY,
    '__module__' : 'peacock_pb2'
    # @@protoc_insertion_point(class_scope:peacock.GetUSLEIData_Reply.UsLeiDataMapEntry)
    })
  ,
  'DESCRIPTOR' : _GETUSLEIDATA_REPLY,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.GetUSLEIData_Reply)
  })
_sym_db.RegisterMessage(GetUSLEIData_Reply)
_sym_db.RegisterMessage(GetUSLEIData_Reply.UsLeiDataMapEntry)

RemoveStrategyConfig_Msg = _reflection.GeneratedProtocolMessageType('RemoveStrategyConfig_Msg', (_message.Message,), {
  'DESCRIPTOR' : _REMOVESTRATEGYCONFIG_MSG,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.RemoveStrategyConfig_Msg)
  })
_sym_db.RegisterMessage(RemoveStrategyConfig_Msg)

RemoveOldConfig_Msg = _reflection.GeneratedProtocolMessageType('RemoveOldConfig_Msg', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEOLDCONFIG_MSG,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.RemoveOldConfig_Msg)
  })
_sym_db.RegisterMessage(RemoveOldConfig_Msg)

Dummy_Reply = _reflection.GeneratedProtocolMessageType('Dummy_Reply', (_message.Message,), {
  'DESCRIPTOR' : _DUMMY_REPLY,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.Dummy_Reply)
  })
_sym_db.RegisterMessage(Dummy_Reply)

GetStrategyConfig_Msg = _reflection.GeneratedProtocolMessageType('GetStrategyConfig_Msg', (_message.Message,), {
  'DESCRIPTOR' : _GETSTRATEGYCONFIG_MSG,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.GetStrategyConfig_Msg)
  })
_sym_db.RegisterMessage(GetStrategyConfig_Msg)

GetStrategyConfig_Reply = _reflection.GeneratedProtocolMessageType('GetStrategyConfig_Reply', (_message.Message,), {
  'DESCRIPTOR' : _GETSTRATEGYCONFIG_REPLY,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.GetStrategyConfig_Reply)
  })
_sym_db.RegisterMessage(GetStrategyConfig_Reply)

SaveStrategyConfig_Msg = _reflection.GeneratedProtocolMessageType('SaveStrategyConfig_Msg', (_message.Message,), {
  'DESCRIPTOR' : _SAVESTRATEGYCONFIG_MSG,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.SaveStrategyConfig_Msg)
  })
_sym_db.RegisterMessage(SaveStrategyConfig_Msg)

SaveStrategyConfig_Reply = _reflection.GeneratedProtocolMessageType('SaveStrategyConfig_Reply', (_message.Message,), {
  'DESCRIPTOR' : _SAVESTRATEGYCONFIG_REPLY,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.SaveStrategyConfig_Reply)
  })
_sym_db.RegisterMessage(SaveStrategyConfig_Reply)

SaveFileToColud_Msg = _reflection.GeneratedProtocolMessageType('SaveFileToColud_Msg', (_message.Message,), {
  'DESCRIPTOR' : _SAVEFILETOCOLUD_MSG,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.SaveFileToColud_Msg)
  })
_sym_db.RegisterMessage(SaveFileToColud_Msg)

SaveRefDataPriceFromQC_Msg = _reflection.GeneratedProtocolMessageType('SaveRefDataPriceFromQC_Msg', (_message.Message,), {
  'DESCRIPTOR' : _SAVEREFDATAPRICEFROMQC_MSG,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.SaveRefDataPriceFromQC_Msg)
  })
_sym_db.RegisterMessage(SaveRefDataPriceFromQC_Msg)

SaveRefDataFromQC_Msg = _reflection.GeneratedProtocolMessageType('SaveRefDataFromQC_Msg', (_message.Message,), {
  'DESCRIPTOR' : _SAVEREFDATAFROMQC_MSG,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.SaveRefDataFromQC_Msg)
  })
_sym_db.RegisterMessage(SaveRefDataFromQC_Msg)

NoneReply = _reflection.GeneratedProtocolMessageType('NoneReply', (_message.Message,), {
  'DESCRIPTOR' : _NONEREPLY,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.NoneReply)
  })
_sym_db.RegisterMessage(NoneReply)

Ping = _reflection.GeneratedProtocolMessageType('Ping', (_message.Message,), {
  'DESCRIPTOR' : _PING,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.Ping)
  })
_sym_db.RegisterMessage(Ping)

Pong = _reflection.GeneratedProtocolMessageType('Pong', (_message.Message,), {
  'DESCRIPTOR' : _PONG,
  '__module__' : 'peacock_pb2'
  # @@protoc_insertion_point(class_scope:peacock.Pong)
  })
_sym_db.RegisterMessage(Pong)


_GETUSLEIDATA_REPLY_USLEIDATAMAPENTRY._options = None

_PEACOCK = _descriptor.ServiceDescriptor(
  name='Peacock',
  full_name='peacock.Peacock',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1247,
  serialized_end=2119,
  methods=[
  _descriptor.MethodDescriptor(
    name='SaveFileToColud',
    full_name='peacock.Peacock.SaveFileToColud',
    index=0,
    containing_service=None,
    input_type=_SAVEFILETOCOLUD_MSG,
    output_type=_NONEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SaveRefDataPriceFromQC',
    full_name='peacock.Peacock.SaveRefDataPriceFromQC',
    index=1,
    containing_service=None,
    input_type=_SAVEREFDATAPRICEFROMQC_MSG,
    output_type=_NONEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SaveRefDataFromQC',
    full_name='peacock.Peacock.SaveRefDataFromQC',
    index=2,
    containing_service=None,
    input_type=_SAVEREFDATAFROMQC_MSG,
    output_type=_NONEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SaveStrategyConfig',
    full_name='peacock.Peacock.SaveStrategyConfig',
    index=3,
    containing_service=None,
    input_type=_SAVESTRATEGYCONFIG_MSG,
    output_type=_SAVESTRATEGYCONFIG_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStrategyConfig',
    full_name='peacock.Peacock.GetStrategyConfig',
    index=4,
    containing_service=None,
    input_type=_GETSTRATEGYCONFIG_MSG,
    output_type=_GETSTRATEGYCONFIG_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveStrategyConfig',
    full_name='peacock.Peacock.RemoveStrategyConfig',
    index=5,
    containing_service=None,
    input_type=_REMOVESTRATEGYCONFIG_MSG,
    output_type=_DUMMY_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveOldConfig',
    full_name='peacock.Peacock.RemoveOldConfig',
    index=6,
    containing_service=None,
    input_type=_REMOVEOLDCONFIG_MSG,
    output_type=_DUMMY_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataByStrategyId',
    full_name='peacock.Peacock.GetDataByStrategyId',
    index=7,
    containing_service=None,
    input_type=_GETDATABYSTRATEGYID_MSG,
    output_type=_GETDATABYSTRATEGYID_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBacktestWarmupData',
    full_name='peacock.Peacock.GetBacktestWarmupData',
    index=8,
    containing_service=None,
    input_type=_GETBACKTESTWARMUPDATA_MSG,
    output_type=_GETBACKTESTWARMUPDATA_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUSLEIData',
    full_name='peacock.Peacock.GetUSLEIData',
    index=9,
    containing_service=None,
    input_type=_GETUSLEIDATA_MSG,
    output_type=_GETUSLEIDATA_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HealthCheck',
    full_name='peacock.Peacock.HealthCheck',
    index=10,
    containing_service=None,
    input_type=_PING,
    output_type=_PONG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PEACOCK)

DESCRIPTOR.services_by_name['Peacock'] = _PEACOCK

# @@protoc_insertion_point(module_scope)
