# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tweety.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tweety.proto',
  package='tweety',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0ctweety.proto\x12\x06tweety\"\\\n\x18RemoveStrategyConfig_Msg\x12\x15\n\rstrategy_name\x18\x01 \x01(\t\x12\x0f\n\x07is_live\x18\x02 \x01(\x08\x12\x18\n\x10strategy_id_list\x18\x03 \x03(\t\"#\n\x13RemoveOldConfig_Msg\x12\x0c\n\x04\x64\x61ys\x18\x01 \x01(\x05\"\x1c\n\x0b\x44ummy_Reply\x12\r\n\x05\x64ummy\x18\x01 \x01(\t\"?\n\x15GetStrategyConfig_Msg\x12\x15\n\rstrategy_name\x18\x01 \x01(\t\x12\x0f\n\x07is_live\x18\x02 \x01(\x08\";\n\x17GetStrategyConfig_Reply\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x10\n\x08\x63\x66g_list\x18\x02 \x03(\t\"2\n\x17GetStrategyConfigId_Msg\x12\x17\n\x0fstrategy_config\x18\x01 \x01(\t\";\n\x19GetStrategyConfigId_Reply\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0e\n\x06\x63\x66g_id\x18\x02 \x01(\t\"1\n\x16SaveStrategyConfig_Msg\x12\x17\n\x0fstrategy_config\x18\x01 \x01(\t\"*\n\x18SaveStrategyConfig_Reply\x12\x0e\n\x06status\x18\x01 \x01(\t\"\x17\n\x04Ping\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x17\n\x04Pong\x12\x0f\n\x07message\x18\x01 \x01(\t2\xcf\x03\n\x06Tweety\x12Y\n\x13GetStrategyConfigId\x12\x1f.tweety.GetStrategyConfigId_Msg\x1a!.tweety.GetStrategyConfigId_Reply\x12V\n\x12SaveStrategyConfig\x12\x1e.tweety.SaveStrategyConfig_Msg\x1a .tweety.SaveStrategyConfig_Reply\x12S\n\x11GetStrategyConfig\x12\x1d.tweety.GetStrategyConfig_Msg\x1a\x1f.tweety.GetStrategyConfig_Reply\x12M\n\x14RemoveStrategyConfig\x12 .tweety.RemoveStrategyConfig_Msg\x1a\x13.tweety.Dummy_Reply\x12\x43\n\x0fRemoveOldConfig\x12\x1b.tweety.RemoveOldConfig_Msg\x1a\x13.tweety.Dummy_Reply\x12)\n\x0bHealthCheck\x12\x0c.tweety.Ping\x1a\x0c.tweety.Pongb\x06proto3'
)




_REMOVESTRATEGYCONFIG_MSG = _descriptor.Descriptor(
  name='RemoveStrategyConfig_Msg',
  full_name='tweety.RemoveStrategyConfig_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_name', full_name='tweety.RemoveStrategyConfig_Msg.strategy_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_live', full_name='tweety.RemoveStrategyConfig_Msg.is_live', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strategy_id_list', full_name='tweety.RemoveStrategyConfig_Msg.strategy_id_list', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=116,
)


_REMOVEOLDCONFIG_MSG = _descriptor.Descriptor(
  name='RemoveOldConfig_Msg',
  full_name='tweety.RemoveOldConfig_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='days', full_name='tweety.RemoveOldConfig_Msg.days', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=153,
)


_DUMMY_REPLY = _descriptor.Descriptor(
  name='Dummy_Reply',
  full_name='tweety.Dummy_Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dummy', full_name='tweety.Dummy_Reply.dummy', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=183,
)


_GETSTRATEGYCONFIG_MSG = _descriptor.Descriptor(
  name='GetStrategyConfig_Msg',
  full_name='tweety.GetStrategyConfig_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_name', full_name='tweety.GetStrategyConfig_Msg.strategy_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_live', full_name='tweety.GetStrategyConfig_Msg.is_live', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=248,
)


_GETSTRATEGYCONFIG_REPLY = _descriptor.Descriptor(
  name='GetStrategyConfig_Reply',
  full_name='tweety.GetStrategyConfig_Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='tweety.GetStrategyConfig_Reply.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cfg_list', full_name='tweety.GetStrategyConfig_Reply.cfg_list', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=309,
)


_GETSTRATEGYCONFIGID_MSG = _descriptor.Descriptor(
  name='GetStrategyConfigId_Msg',
  full_name='tweety.GetStrategyConfigId_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_config', full_name='tweety.GetStrategyConfigId_Msg.strategy_config', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=311,
  serialized_end=361,
)


_GETSTRATEGYCONFIGID_REPLY = _descriptor.Descriptor(
  name='GetStrategyConfigId_Reply',
  full_name='tweety.GetStrategyConfigId_Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='tweety.GetStrategyConfigId_Reply.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cfg_id', full_name='tweety.GetStrategyConfigId_Reply.cfg_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=363,
  serialized_end=422,
)


_SAVESTRATEGYCONFIG_MSG = _descriptor.Descriptor(
  name='SaveStrategyConfig_Msg',
  full_name='tweety.SaveStrategyConfig_Msg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='strategy_config', full_name='tweety.SaveStrategyConfig_Msg.strategy_config', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=473,
)


_SAVESTRATEGYCONFIG_REPLY = _descriptor.Descriptor(
  name='SaveStrategyConfig_Reply',
  full_name='tweety.SaveStrategyConfig_Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='tweety.SaveStrategyConfig_Reply.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=475,
  serialized_end=517,
)


_PING = _descriptor.Descriptor(
  name='Ping',
  full_name='tweety.Ping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='tweety.Ping.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=542,
)


_PONG = _descriptor.Descriptor(
  name='Pong',
  full_name='tweety.Pong',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='tweety.Pong.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=544,
  serialized_end=567,
)

DESCRIPTOR.message_types_by_name['RemoveStrategyConfig_Msg'] = _REMOVESTRATEGYCONFIG_MSG
DESCRIPTOR.message_types_by_name['RemoveOldConfig_Msg'] = _REMOVEOLDCONFIG_MSG
DESCRIPTOR.message_types_by_name['Dummy_Reply'] = _DUMMY_REPLY
DESCRIPTOR.message_types_by_name['GetStrategyConfig_Msg'] = _GETSTRATEGYCONFIG_MSG
DESCRIPTOR.message_types_by_name['GetStrategyConfig_Reply'] = _GETSTRATEGYCONFIG_REPLY
DESCRIPTOR.message_types_by_name['GetStrategyConfigId_Msg'] = _GETSTRATEGYCONFIGID_MSG
DESCRIPTOR.message_types_by_name['GetStrategyConfigId_Reply'] = _GETSTRATEGYCONFIGID_REPLY
DESCRIPTOR.message_types_by_name['SaveStrategyConfig_Msg'] = _SAVESTRATEGYCONFIG_MSG
DESCRIPTOR.message_types_by_name['SaveStrategyConfig_Reply'] = _SAVESTRATEGYCONFIG_REPLY
DESCRIPTOR.message_types_by_name['Ping'] = _PING
DESCRIPTOR.message_types_by_name['Pong'] = _PONG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RemoveStrategyConfig_Msg = _reflection.GeneratedProtocolMessageType('RemoveStrategyConfig_Msg', (_message.Message,), {
  'DESCRIPTOR' : _REMOVESTRATEGYCONFIG_MSG,
  '__module__' : 'tweety_pb2'
  # @@protoc_insertion_point(class_scope:tweety.RemoveStrategyConfig_Msg)
  })
_sym_db.RegisterMessage(RemoveStrategyConfig_Msg)

RemoveOldConfig_Msg = _reflection.GeneratedProtocolMessageType('RemoveOldConfig_Msg', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEOLDCONFIG_MSG,
  '__module__' : 'tweety_pb2'
  # @@protoc_insertion_point(class_scope:tweety.RemoveOldConfig_Msg)
  })
_sym_db.RegisterMessage(RemoveOldConfig_Msg)

Dummy_Reply = _reflection.GeneratedProtocolMessageType('Dummy_Reply', (_message.Message,), {
  'DESCRIPTOR' : _DUMMY_REPLY,
  '__module__' : 'tweety_pb2'
  # @@protoc_insertion_point(class_scope:tweety.Dummy_Reply)
  })
_sym_db.RegisterMessage(Dummy_Reply)

GetStrategyConfig_Msg = _reflection.GeneratedProtocolMessageType('GetStrategyConfig_Msg', (_message.Message,), {
  'DESCRIPTOR' : _GETSTRATEGYCONFIG_MSG,
  '__module__' : 'tweety_pb2'
  # @@protoc_insertion_point(class_scope:tweety.GetStrategyConfig_Msg)
  })
_sym_db.RegisterMessage(GetStrategyConfig_Msg)

GetStrategyConfig_Reply = _reflection.GeneratedProtocolMessageType('GetStrategyConfig_Reply', (_message.Message,), {
  'DESCRIPTOR' : _GETSTRATEGYCONFIG_REPLY,
  '__module__' : 'tweety_pb2'
  # @@protoc_insertion_point(class_scope:tweety.GetStrategyConfig_Reply)
  })
_sym_db.RegisterMessage(GetStrategyConfig_Reply)

GetStrategyConfigId_Msg = _reflection.GeneratedProtocolMessageType('GetStrategyConfigId_Msg', (_message.Message,), {
  'DESCRIPTOR' : _GETSTRATEGYCONFIGID_MSG,
  '__module__' : 'tweety_pb2'
  # @@protoc_insertion_point(class_scope:tweety.GetStrategyConfigId_Msg)
  })
_sym_db.RegisterMessage(GetStrategyConfigId_Msg)

GetStrategyConfigId_Reply = _reflection.GeneratedProtocolMessageType('GetStrategyConfigId_Reply', (_message.Message,), {
  'DESCRIPTOR' : _GETSTRATEGYCONFIGID_REPLY,
  '__module__' : 'tweety_pb2'
  # @@protoc_insertion_point(class_scope:tweety.GetStrategyConfigId_Reply)
  })
_sym_db.RegisterMessage(GetStrategyConfigId_Reply)

SaveStrategyConfig_Msg = _reflection.GeneratedProtocolMessageType('SaveStrategyConfig_Msg', (_message.Message,), {
  'DESCRIPTOR' : _SAVESTRATEGYCONFIG_MSG,
  '__module__' : 'tweety_pb2'
  # @@protoc_insertion_point(class_scope:tweety.SaveStrategyConfig_Msg)
  })
_sym_db.RegisterMessage(SaveStrategyConfig_Msg)

SaveStrategyConfig_Reply = _reflection.GeneratedProtocolMessageType('SaveStrategyConfig_Reply', (_message.Message,), {
  'DESCRIPTOR' : _SAVESTRATEGYCONFIG_REPLY,
  '__module__' : 'tweety_pb2'
  # @@protoc_insertion_point(class_scope:tweety.SaveStrategyConfig_Reply)
  })
_sym_db.RegisterMessage(SaveStrategyConfig_Reply)

Ping = _reflection.GeneratedProtocolMessageType('Ping', (_message.Message,), {
  'DESCRIPTOR' : _PING,
  '__module__' : 'tweety_pb2'
  # @@protoc_insertion_point(class_scope:tweety.Ping)
  })
_sym_db.RegisterMessage(Ping)

Pong = _reflection.GeneratedProtocolMessageType('Pong', (_message.Message,), {
  'DESCRIPTOR' : _PONG,
  '__module__' : 'tweety_pb2'
  # @@protoc_insertion_point(class_scope:tweety.Pong)
  })
_sym_db.RegisterMessage(Pong)



_TWEETY = _descriptor.ServiceDescriptor(
  name='Tweety',
  full_name='tweety.Tweety',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=570,
  serialized_end=1033,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetStrategyConfigId',
    full_name='tweety.Tweety.GetStrategyConfigId',
    index=0,
    containing_service=None,
    input_type=_GETSTRATEGYCONFIGID_MSG,
    output_type=_GETSTRATEGYCONFIGID_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SaveStrategyConfig',
    full_name='tweety.Tweety.SaveStrategyConfig',
    index=1,
    containing_service=None,
    input_type=_SAVESTRATEGYCONFIG_MSG,
    output_type=_SAVESTRATEGYCONFIG_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStrategyConfig',
    full_name='tweety.Tweety.GetStrategyConfig',
    index=2,
    containing_service=None,
    input_type=_GETSTRATEGYCONFIG_MSG,
    output_type=_GETSTRATEGYCONFIG_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveStrategyConfig',
    full_name='tweety.Tweety.RemoveStrategyConfig',
    index=3,
    containing_service=None,
    input_type=_REMOVESTRATEGYCONFIG_MSG,
    output_type=_DUMMY_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveOldConfig',
    full_name='tweety.Tweety.RemoveOldConfig',
    index=4,
    containing_service=None,
    input_type=_REMOVEOLDCONFIG_MSG,
    output_type=_DUMMY_REPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HealthCheck',
    full_name='tweety.Tweety.HealthCheck',
    index=5,
    containing_service=None,
    input_type=_PING,
    output_type=_PONG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TWEETY)

DESCRIPTOR.services_by_name['Tweety'] = _TWEETY

# @@protoc_insertion_point(module_scope)
